SHADER FOR TERRAIN



vertex shader:	[s:

varying vec4 diffuse, ambient;
varying vec3 normal, lightDir0, lightDir1, lightDir2;
varying float dist1, dist2;

void main()
{   
   vec4 ecPos;
   vec4 col;
   vec3 aux1, aux2;
   
   /* first transform the normal into eye space and normalize the result */
   normal = normalize(gl_NormalMatrix * gl_Normal);
   
   /* now normalize the light's direction. Note that according to the
   OpenGL specification, the light is stored in eye space.*/
   ecPos = gl_ModelViewMatrix * gl_Vertex;
   aux1 = vec3(gl_LightSource[1].position-ecPos);
   lightDir1 = normalize(aux1);
   aux2 = vec3(gl_LightSource[2].position-ecPos);
   lightDir2 = normalize(aux2);
   
   /* compute the distance to the light source to a varying variable*/
   dist1 = length(aux1);
   dist2 = length(aux2);

   /* Compute the diffuse, ambient and globalAmbient terms */
   diffuse = gl_FrontMaterial.diffuse * (gl_LightSource[1].diffuse +
                                         gl_LightSource[2].diffuse);
   ambient = gl_FrontMaterial.ambient * (gl_LightSource[1].ambient +
                                         gl_LightSource[2].ambient);
   
   /* here is the global light */
   lightDir0 = normalize(vec3(gl_LightSource[0].position));
   
   gl_FrontColor = gl_FrontMaterial.ambient * (gl_LightSource[0].ambient + gl_LightModel.ambient);
   gl_FrontSecondaryColor = gl_FrontMaterial.diffuse * gl_LightSource[0].diffuse * 10.0;
   
   /* and the texture */
   //gl_TexCoord[0] = gl_MultiTexCoord0;
   
   gl_Position = ftransform();   
} 

]



fragment shader:	[s:

varying vec4 diffuse, ambient;
varying vec3 normal, lightDir0, lightDir1, lightDir2;
varying float dist1, dist2;
//uniform sampler2D tex;


void main()
{
   vec3 n;
   float NdotL0, NdotL1, NdotL2;
   vec4 color = gl_Color;
   float att1, att2, spotEffect1, spotEffect2;
   vec4 texel;
   
   /* a fragment shader can't write a verying variable, hence we need
   a new variable to store the normalized interpolated normal */
   n = normalize(normal);
   
   /* compute the dot product between normal and ldir */
   NdotL0 = max(dot(n,lightDir0),0.0);
   NdotL1 = max(dot(n,normalize(lightDir1)),0.0);
   NdotL2 = max(dot(n,normalize(lightDir2)),0.0);
   
   /* the global light */
   if (NdotL0 > 0.0) {
      color += gl_SecondaryColor * NdotL0;
   }
   
   /* the first rover light */
   //if (NdotL1 > 0.0) {
      spotEffect1 = dot(normalize(gl_LightSource[1].spotDirection), normalize(-lightDir1));
      if (spotEffect1 > gl_LightSource[1].spotCosCutoff) {
         spotEffect1 = pow(spotEffect1, gl_LightSource[1].spotExponent);
         att1 = spotEffect1 / (gl_LightSource[1].constantAttenuation +
               gl_LightSource[1].linearAttenuation * dist1 +
               gl_LightSource[1].quadraticAttenuation * dist1 * dist1);
         
            
         color += att1 * (diffuse * NdotL1 + ambient);
      }
   //}
   
   /* the second rover light */
   //if (NdotL2 > 0.0) {
      spotEffect2 = dot(normalize(gl_LightSource[2].spotDirection), normalize(-lightDir2));
      if (spotEffect2 > gl_LightSource[2].spotCosCutoff) {
         spotEffect2 = pow(spotEffect2, gl_LightSource[2].spotExponent);
         att2 = spotEffect2 / (gl_LightSource[2].constantAttenuation +
               gl_LightSource[2].linearAttenuation * dist2 +
               gl_LightSource[2].quadraticAttenuation * dist2 * dist2);
         
            
         color += att2 * (diffuse * NdotL2 + ambient);
      }
      
   //}
   
   /* the texture */
   /*texel = texture2D(tex,gl_TexCoord[0].st);
   gl_FragColor = vec4(color * texel);*/
   
   gl_FragColor = color;
}

]
